@@ -127,12 +127,13 @@ JS_BEGIN_EXTERN_C
 #define JSPROP_INDEX            0x80    /* name is actually (jsint) index */
 
 /* Function flags, set in JSFunctionSpec and passed to JS_NewFunction etc. */
+#define	JSFUN_NODECOMPILE     	0x04	/* cannot be decompiled */
 #define JSFUN_LAMBDA            0x08    /* expressed, not declared, function */
 #define JSFUN_GETTER            JSPROP_GETTER
 #define JSFUN_SETTER            JSPROP_SETTER
 #define JSFUN_BOUND_METHOD      0x40    /* bind this to fun->object's parent */
 #define JSFUN_HEAVYWEIGHT       0x80    /* activation requires a Call object */
-#define JSFUN_FLAGS_MASK        0xf8    /* overlay JSFUN_* attributes */
+#define JSFUN_FLAGS_MASK        0xfc    /* overlay JSFUN_* attributes */
 
 /*
  * Well-known JS values.  The extern'd variables are initialized when the
@@ -403,6 +404,12 @@ JS_GetContextPrivate(JSContext *cx);
 extern JS_PUBLIC_API(void)
 JS_SetContextPrivate(JSContext *cx, void *data);
 
+extern JS_PUBLIC_API(JSBool)
+JS_GetContextCaseSensitive (JSContext *cx);
+
+extern JS_PUBLIC_API(void)
+JS_SetContextCaseSensitive (JSContext *cx, JSBool caseSensitive);
+
 extern JS_PUBLIC_API(JSRuntime *)
 JS_GetRuntime(JSContext *cx);
 
@@ -806,7 +813,7 @@ struct JSProperty {
 };
 
 struct JSIdArray {
-    jsint length;
+    jsuint length;
     jsid  vector[1];    /* actually, length jsid words */
 };
 
@@ -870,7 +877,7 @@ struct JSFunctionSpec {
 
 extern JS_PUBLIC_API(JSObject *)
 JS_InitClass(JSContext *cx, JSObject *obj, JSObject *parent_proto,
-             JSClass *clasp, JSNative constructor, uintN nargs,
+             const JSClass *clasp, JSNative constructor, uintN nargs,
              JSPropertySpec *ps, JSFunctionSpec *fs,
              JSPropertySpec *static_ps, JSFunctionSpec *static_fs);
 
@@ -887,7 +894,7 @@ JS_GetClass(JSObject *obj);
 #endif
 
 extern JS_PUBLIC_API(JSBool)
-JS_InstanceOf(JSContext *cx, JSObject *obj, JSClass *clasp, jsval *argv);
+JS_InstanceOf(JSContext *cx, JSObject *obj, const JSClass *clasp, jsval *argv);
 
 extern JS_PUBLIC_API(void *)
 JS_GetPrivate(JSContext *cx, JSObject *obj);
@@ -923,7 +930,7 @@ extern JS_PUBLIC_API(JSBool)
 JS_GetObjectId(JSContext *cx, JSObject *obj, jsid *idp);
 
 extern JS_PUBLIC_API(JSObject *)
-JS_NewObject(JSContext *cx, JSClass *clasp, JSObject *proto, JSObject *parent);
+JS_NewObject(JSContext *cx, const JSClass *clasp, JSObject *proto, JSObject *parent);
 
 extern JS_PUBLIC_API(JSBool)
 JS_SealObject(JSContext *cx, JSObject *obj, JSBool deep);
