@@ -847,8 +847,9 @@ js_MarkGCThing(JSContext *cx, void *thing, void *arg)
               rt->gcStats.maxdepth = rt->gcStats.depth);
 
 #ifdef GC_MARK_DEBUG
-    if (js_DumpGCHeap)
-        gc_dump_thing(thing, flags, arg, js_DumpGCHeap);
+    if (!js_DumpGCHeap)
+      js_DumpGCHeap = stderr;
+    gc_dump_thing(thing, flags, arg, js_DumpGCHeap);
 #endif
 
     switch (flags & GCF_TYPEMASK) {
@@ -1151,7 +1152,7 @@ js_GC(JSContext *cx, uintN gcflags)
         return;
 
 #endif /* !JS_THREADSAFE */
-fprintf(stderr, "Doing the GC thing!\n"); /* FIXME */
+//fprintf(stderr, "Doing the GC thing!\n"); /* FIXME */
     /*
      * Set rt->gcRunning here within the GC lock, and after waiting for any
      * active requests to end, so that new requests that try to JS_AddRoot,
@@ -1214,20 +1215,23 @@ restart:
                     GC_MARK(cx, fp->argsobj, "arguments object", NULL);
                 if (fp->varobj)
                     GC_MARK(cx, fp->varobj, "variables object", NULL);
-                if (fp->script) {
+                if (fp->script)
                     js_MarkScript(cx, fp->script, NULL);
-                    if (fp->spbase) {
-                        /*
-                         * Don't mark what has not been pushed yet, or what
-                         * has been popped already.
-                         */
-                        depth = fp->script->depth;
-                        nslots = (JS_UPTRDIFF(fp->sp, fp->spbase)
-                                  < depth * sizeof(jsval))
-                                 ? (uintN)(fp->sp - fp->spbase)
-                                 : depth;
-                        GC_MARK_JSVALS(cx, nslots, fp->spbase, "operand");
-                    }
+		if (fp->spbase) {
+		    /*
+		     * Don't mark what has not been pushed yet, or what
+		     * has been popped already.
+		     */
+		    if (fp->script) {
+		      depth = fp->script->depth;
+		      nslots = (JS_UPTRDIFF(fp->sp, fp->spbase)
+				< depth * sizeof(jsval))
+			       ? (uintN)(fp->sp - fp->spbase)
+			       : depth;
+		    } else {
+		      nslots = (uintN) (fp->sp - fp->spbase);
+		    }
+                    GC_MARK_JSVALS(cx, nslots, fp->spbase, "operand");
                 }
                 GC_MARK(cx, fp->thisp, "this", NULL);
                 if (fp->argv) {
